@@ -1,76 +1,79 @@
-'''
+"""
 Created on 2021-10-21
 
 @author: wf
-'''
-import os
-from unittest import TestCase
-import time
+"""
+
 import getpass
+import os
+import time
 import warnings
+from unittest import TestCase
 
 from wikibot3rd.wikiuser import WikiUser
 
 
 class Profiler:
-    '''
+    """
     simple profiler
-    '''
-    def __init__(self,msg,profile=True):
-        '''
+    """
+
+    def __init__(self, msg, profile=True):
+        """
         construct me with the given msg and profile active flag
-        
+
         Args:
             msg(str): the message to show if profiling is active
             profile(bool): True if messages should be shown
-        '''
-        self.msg=msg
-        self.profile=profile
-        self.starttime=time.time()
+        """
+        self.msg = msg
+        self.profile = profile
+        self.starttime = time.time()
         if profile:
             print(f"Starting {msg} ...")
         warnings.simplefilter("ignore", ResourceWarning)
-    
-    def time(self,extraMsg=""):
-        '''
+
+    def time(self, extraMsg=""):
+        """
         time the action and print if profile is active
-        '''
-        elapsed=time.time()-self.starttime
+        """
+        elapsed = time.time() - self.starttime
         if self.profile:
             print(f"{self.msg}{extraMsg} took {elapsed:5.3f} s")
         return elapsed
 
+
 class BaseTest(TestCase):
-    '''
+    """
     base Test class
-    '''
-    
-    def setUp(self,debug=False,profile=True):
-        '''
+    """
+
+    def setUp(self, debug=False, profile=True):
+        """
         setUp test environment
-        '''
+        """
         TestCase.setUp(self)
-        self.debug=debug
-        msg=f"test {self._testMethodName} ... with debug={self.debug}"
+        self.debug = debug
+        msg = f"test {self._testMethodName} ... with debug={self.debug}"
         # make sure there is an EventCorpus.db to speed up tests
-        self.profiler=Profiler(msg=msg,profile=profile)
-        self.wikiId = 'smwcopy'
-        
+        self.profiler = Profiler(msg=msg, profile=profile)
+        self.wikiId = "smwcopy"
+
     def tearDown(self):
         self.profiler.time()
         pass
-        
-    @staticmethod    
+
+    @staticmethod
     def isInPublicCI():
-        '''
+        """
         are we running in a public Continuous Integration Environment?
-        '''
+        """
         return getpass.getuser() in ["travis", "runner"]
-    
+
     def inPublicCI(self):
         return BaseTest.isInPublicCI()
 
-    def getWikiUser(self, wikiId:str=None) -> WikiUser:
+    def getWikiUser(self, wikiId: str = None) -> WikiUser:
         """
         Get WikiUser for given wikiId
 
@@ -85,27 +88,54 @@ class BaseTest(TestCase):
         wikiUser = self.getSMW_WikiUser(wikiId=wikiId, save=self.inPublicCI())
         return wikiUser
 
-    def getSMW_WikiUser(self, wikiId="or", save=False) -> WikiUser:
-        '''
-        get semantic media wiki users for SemanticMediawiki.org and openresearch.org
-        '''
+    def get_wiki_user(self, wikiId="or", save=False) -> WikiUser:
+        """
+        get wiki users for given wikiId
+        """
         iniFile = WikiUser.iniFilePath(wikiId)
         wikiUser = None
         if not os.path.isfile(iniFile):
             wikiDict = None
             if wikiId == "or":
-                wikiDict = {"wikiId": wikiId, "email": "noreply@nouser.com", "url": "https://www.openresearch.org",
-                            "scriptPath": "/mediawiki/", "version": "MediaWiki 1.31.1"}
+                wikiDict = {
+                    "wikiId": wikiId,
+                    "email": "noreply@nouser.com",
+                    "url": "https://www.openresearch.org",
+                    "scriptPath": "/mediawiki/",
+                    "version": "MediaWiki 1.31.1",
+                }
             if wikiId == "cr":
-                wikiDict = {"wikiId": wikiId, "email": "noreply@nouser.com", "url": "http://cr.bitplan.com",
-                            "scriptPath": "", "version": "MediaWiki 1.35.5"}    
+                wikiDict = {
+                    "wikiId": wikiId,
+                    "email": "noreply@nouser.com",
+                    "url": "http://cr.bitplan.com",
+                    "scriptPath": "",
+                    "version": "MediaWiki 1.35.5",
+                }
+            if wikiId == "genealogy":
+                wikiDict = {
+                    "wikiId": wikiId,
+                    "email": "noreply@nouser.com",
+                    "url": "https://wiki.genealogy.net",
+                    "scriptPath": "/",
+                    "version": "MediaWiki 1.35.11",
+                }
             if wikiId in ["orclone", "orcopy"]:
-                wikiDict = {"wikiId": wikiId, "email": "noreply@nouser.com",
-                            "url": "https://confident.dbis.rwth-aachen.de", "scriptPath": "/or/",
-                            "version": "MediaWiki 1.35.1"}
+                wikiDict = {
+                    "wikiId": wikiId,
+                    "email": "noreply@nouser.com",
+                    "url": "https://confident.dbis.rwth-aachen.de",
+                    "scriptPath": "/or/",
+                    "version": "MediaWiki 1.35.1",
+                }
             if wikiId == "smwcopy":
-                wikiDict = {"wikiId": wikiId, "email": "noreply@nouser.com", "url": "https://smw.bitplan.com/",
-                            "scriptPath": "", "version": "MediaWiki 1.35.5"}
+                wikiDict = {
+                    "wikiId": wikiId,
+                    "email": "noreply@nouser.com",
+                    "url": "https://smw.bitplan.com/",
+                    "scriptPath": "",
+                    "version": "MediaWiki 1.35.5",
+                }
             if wikiDict is None:
                 raise Exception(f"wikiId {wikiId} is not known")
             else:
@@ -114,4 +144,8 @@ class BaseTest(TestCase):
                     wikiUser.save()
         else:
             wikiUser = WikiUser.ofWikiId(wikiId, lenient=True)
-        return wikiUser
\ No newline at end of file
+        return wikiUser
+
+    def getSMW_WikiUser(self, wikiId="or", save=False) -> WikiUser:
+        wiki_user=self.get_wiki_user(wikiId, save)
+        return wiki_user
