@@ -1,26 +1,27 @@
-'''
+"""
 Created on 2021-02-16
 
 @author: wf
-'''
+"""
+
 import json
 import unittest
 from contextlib import redirect_stdout
 from io import StringIO
-from wikibot3rd.wikiclient import WikiClient
-from tests.test_WikiUser import TestWikiUser
-from wikibot3rd.wikipush import WikiPush, mainQuery
+
 from tests.basetest import BaseTest
+from tests.test_WikiUser import TestWikiUser
+from wikibot3rd.wikiclient import WikiClient
+from wikibot3rd.wikipush import WikiPush, mainQuery
 
 
 class TestWikiQuery(BaseTest):
-    '''
+    """
     tests for https://github.com/WolfgangFahl/py-3rdparty-mediawiki/issues/56
-    '''
+    """
 
-    def setUp(self, debug:bool=False, profile:bool=True):
-        """
-        """
+    def setUp(self, debug: bool = False, profile: bool = True):
+        """ """
         super().setUp(debug, profile)
         self.eventQuery = """{{#ask: [[IsA::Event]]
 |mainlabel=Event
@@ -41,32 +42,43 @@ class TestWikiQuery(BaseTest):
 |format=table
 |limit=10
 }}
-"""   
+"""
         self.getWikiUser("cr")
-        #self.getWikiUser("orcopy")
-        #self.getWikiUser("orclone")
-    
-    def getWikiClient(self,wikiId='cr'):
-        ''' get the alternative SMW access instances for the given wiki id
-        '''
-        wikiuser=TestWikiUser.getSMW_WikiUser(wikiId)
-        wikiclient=WikiClient.ofWikiUser(wikiuser)
+        # self.getWikiUser("orcopy")
+        # self.getWikiUser("orclone")
+
+    def getWikiClient(self, wikiId="cr"):
+        """get the alternative SMW access instances for the given wiki id"""
+        wikiuser = TestWikiUser.getSMW_WikiUser(wikiId)
+        wikiclient = WikiClient.ofWikiUser(wikiuser)
         return wikiclient
 
     def testWikiQuery(self):
-        '''
+        """
         https://github.com/WolfgangFahl/py-3rdparty-mediawiki/issues/56
-        '''
+        """
         # make sure the CI wikiUser is prepared
-        if self.inPublicCI(): return
-        debug=self.debug
-        debug=True
-        wikiId='cr'
-        wikiClient=self.getWikiClient(wikiId)
-        wikiPush=WikiPush(fromWikiId=wikiId)
-        askQuery=self.eventQuery
-        for outputFormat in ["csv","json","xml","ttl","mediawiki","github","latex","lod"]:
-            formatedQueryResults = wikiPush.formatQueryResult(askQuery, wikiClient,outputFormat=outputFormat, entityName="Event")
+        if self.inPublicCI():
+            return
+        debug = self.debug
+        debug = True
+        wikiId = "cr"
+        wikiClient = self.getWikiClient(wikiId)
+        wikiPush = WikiPush(fromWikiId=wikiId)
+        askQuery = self.eventQuery
+        for outputFormat in [
+            "csv",
+            "json",
+            "xml",
+            "ttl",
+            "mediawiki",
+            "github",
+            "latex",
+            "lod",
+        ]:
+            formatedQueryResults = wikiPush.formatQueryResult(
+                askQuery, wikiClient, outputFormat=outputFormat, entityName="Event"
+            )
             if formatedQueryResults:
                 if debug:
                     print(formatedQueryResults)
@@ -77,12 +89,14 @@ class TestWikiQuery(BaseTest):
 
     def testJsonDefault(self):
         """Test if default entityName is set correctly for format json"""
-        argv=["-s","cr","-q",self.eventQuery]
+        argv = ["-s", "cr", "-q", self.eventQuery]
         mystdout = StringIO()
         with redirect_stdout(mystdout):
             mainQuery(argv)
         res = mystdout.getvalue()
-        if self.debug:
+        debug=self.debug
+        #debug=True
+        if debug:
             print(res)
         self.assertTrue("data" in json.loads(res).keys())
         return
@@ -90,7 +104,16 @@ class TestWikiQuery(BaseTest):
     def testJson(self):
         """Test if given entityName is set correctly for format json"""
         entityName = "Event"
-        argv=["-s","cr","-q",self.eventQuery, "--entityName", entityName, "--format", "json"]
+        argv = [
+            "-s",
+            "cr",
+            "-q",
+            self.eventQuery,
+            "--entityName",
+            entityName,
+            "--format",
+            "json",
+        ]
         mystdout = StringIO()
         with redirect_stdout(mystdout):
             mainQuery(argv)
@@ -101,28 +124,28 @@ class TestWikiQuery(BaseTest):
         return
 
     def testCSV(self):
-        '''
+        """
         Test if wikiquery returns CSV format correctly
-        '''
+        """
         entityName = "Event"
-        argv=["-s","cr","-q",self.eventQuery, "--format", "csv"]
+        argv = ["-s", "cr", "-q", self.eventQuery, "--format", "csv"]
         mystdout = StringIO()
         with redirect_stdout(mystdout):
             mainQuery(argv)
         res = mystdout.getvalue()
-        debug=self.debug
-        debug=True
+        debug = self.debug
+        debug = True
         if debug:
             print(res)
         expected_headline = "Event;acronym;description;title;homepage;wikidataid;series;colocated_with;city;country;region;creation date;modification date\n"
         self.assertTrue(res.startswith(expected_headline))
         return
 
-    def  testLOD(self):
-        '''
+    def testLOD(self):
+        """
         Test if LOD is returned correctly if called form api
-        '''
-        wikiId = 'cr'
+        """
+        wikiId = "cr"
         wikiClient = self.getWikiClient(wikiId)
         wikiPush = WikiPush(fromWikiId=wikiId)
         askQuery = self.eventQuery
@@ -131,21 +154,23 @@ class TestWikiQuery(BaseTest):
             print(lod_res)
         self.assertTrue(isinstance(lod_res, list))
         self.assertTrue(isinstance(lod_res[0], dict))
-        
+
     def testIssue66(self):
-        '''
+        """
         test TypeError("'dict_values' object is not subscriptable")
-        '''
-        if self.inPublicCI(): return
-        wikiId= 'wgt'
+        """
+        if self.inPublicCI():
+            return
+        wikiId = "wgt"
         wikiClient = self.getWikiClient(wikiId)
         wikiClient.login()
         wikiPush = WikiPush(fromWikiId=wikiId)
-        askQuery="{{#ask:[[Modification date::+]]}}"
-        lod_res= wikiPush.formatQueryResult(askQuery, wikiClient, queryDivision=10)
+        askQuery = "{{#ask:[[Modification date::+]]}}"
+        lod_res = wikiPush.formatQueryResult(askQuery, wikiClient, queryDivision=10)
         if self.debug:
-            print (lod_res)
+            print(lod_res)
+
 
 if __name__ == "__main__":
-    #import sys;sys.argv = ['', 'Test.testName']
-    unittest.main()
\ No newline at end of file
+    # import sys;sys.argv = ['', 'Test.testName']
+    unittest.main()
